<?php

function edstep_course_settings_form($form, &$form_state) {
  $form['edstep_host_and_auth_host'] = [
    '#type' => 'select',
    '#title' => t('EdStep site'),
    '#default_value' => variable_get('edstep_host', 'https://edstep.com') . '|' . variable_get('edstep_auth_host', 'https://auth.cerpus-course.com'),
    '#options' => [
      'https://edstep.com|https://auth.cerpus-course.com' => t('EdStep.com'),
      'https://edstep-demo1.cerpusdev.net|https://auth-ple.oerdev.net' => t('EdStep demo'),
    ],
    '#required' => TRUE,
  ];

  $form['edstep_auth_client_id'] = [
    '#type' => 'textfield',
    '#title' => t('Client ID'),
    '#default_value' => variable_get('edstep_auth_client_id'),
  ];

  $form['edstep_auth_client_secret'] = [
    '#type' => 'textfield',
    '#title' => t('Client secret'),
    '#default_value' => variable_get('edstep_auth_client_secret'),
  ];

  $form['#submit'][] = 'edstep_course_settings_form_submit';

  return system_settings_form($form);
}

function edstep_course_settings_form_submit($form, &$form_state) {
  list($host, $auth_host) = explode('|', $form_state['values']['edstep_host_and_auth_host']);
  $form_state['values']['edstep_host'] = $host;
  $form_state['values']['edstep_auth_host'] = $auth_host;
  unset($form_state['values']['edstep_host_and_auth_host']);
}

function edstep_course_admin_page_view() {
  $build = array();

  $build['add'] = array(
    '#markup' => '<ul class="action-links"><li>' . l(t('Add course from EdStep'), 'edstep/course/add') . '</li></ul>'
  );

  // Build the sortable table header.
  $header = array(
    'title' => t('Title'),
    'author' => t('Added by'),
    'created' => array('data' => t('Added on'), 'field' => 'ec.created', 'sort' => 'desc')
  );
  $header['operations'] = array('data' => t('Operations'));

  $query = db_select('edstep_course', 'ec')->extend('PagerDefault')->extend('TableSort');

  $ids = $query
    ->fields('ec',array('course_id'))
    ->limit(50)
    ->orderByHeader($header)
    ->execute()
    ->fetchCol();
  $edstep_courses = edstep_course_load_multiple($ids);

  $destination = drupal_get_destination();
  $rows = array();
  foreach ($edstep_courses as $edstep_course) {
    $langcode = entity_language('edstep_course', $edstep_course);
    $uri = entity_uri('edstep_course', $edstep_course);
    $rows[$edstep_course->course_id] = array(
      'title' => array(
        'data' => array(
          '#type' => 'link',
          '#title' => $edstep_course->title,
          '#href' => $uri['path'],
          '#options' => $uri['options'],
        ),
      ),
      'author' => theme('username', array('account' => user_load($edstep_course->uid))),
      'created' => format_date($edstep_course->created, 'short'),
    );
    // Build a list of all the accessible operations for the current edstep_course.
    $operations = array();
    if (edstep_course_access('delete', $edstep_course)) {
      $operations['remove'] = array(
        'title' => t('remove'),
        'href' => 'edstep/course/' . $edstep_course->course_id . '/remove',
        'query' => $destination,
      );
    }
    $rows[$edstep_course->course_id]['operations'] = array();
    if (count($operations) > 1) {
      // Render an unordered list of operations links.
      $rows[$edstep_course->course_id]['operations'] = array(
        'data' => array(
          '#theme' => 'links__edstep_course_operations',
          '#links' => $operations,
          '#attributes' => array('class' => array('links', 'inline')),
        ),
      );
    }
    elseif (!empty($operations)) {
      // Render the first and only operation as a link.
      $link = reset($operations);
      $rows[$edstep_course->course_id]['operations'] = array(
        'data' => array(
          '#type' => 'link',
          '#title' => $link['title'],
          '#href' => $link['href'],
          '#options' => array('query' => $link['query']),
        ),
      );
    }
  }

  $build['edstep_courses'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('No content available.'),
  );

  $build['pager'] = array('#markup' => theme('pager'));
  return $build;
}
