<?php

/**
 * Implements hook_field_storage_info().
 */
function edstep_field_storage_info() {
  return array(
    'edstep_field_storage' => array(
      'label' => t('Dummy field storage for remote data'),
      'description' => t('This storage doesn’t actually store anything but fetches data from EdStep.'),
      'settings' => array(
        'remote_key' => NULL,
      ),
    ),
  );
}

/**
 * Implements hook_field_storage_create_field().
 */
function edstep_field_storage_create_field($field) {
  if(empty($field['storage']['settings']['remote_key'])) {
    throw new FieldException('You must specify remote_key setting when creating a field with edstep_field_storage storage.');
  }
}

/**
 * Implements hook_field_update_forbid().
 *
 * Allow all operations
 */
function edstep_field_update_forbid($field, $prior_field, $has_data) {
  // Do nothing
}

/**
 * Implements hook_field_storage_update_field().
 */
function edstep_field_storage_update_field($field, $prior_field, $has_data) {
  // Do nothing
}

/**
 * Implements hook_field_storage_delete_field().
 */
function edstep_field_storage_delete_field($field) {
  // Do nothing
}

/**
 * Implements hook_field_storage_load().
 */
function edstep_field_storage_load($entity_type, $entities, $age, $fields, $options) {
  foreach ($fields as $field_id => $entity_ids) {
    // By the time this hook runs, the relevant field definitions have been
    // populated and cached in FieldInfo, so calling field_info_field_by_id()
    // on each field individually is more efficient than loading all fields in
    // memory upfront with field_info_field_by_ids().
    $field = field_info_field_by_id($field_id);
    $field_name = $field['field_name'];
    $key = $field['storage']['settings']['remote_key'];
    $type = $field['type'];

    foreach($entity_ids as $entity_id) {
      $entity = $entities[$entity_id];
      try {
        $values = isset($entity->remote) ? $entity->remote->{$key} : array();
      } catch(\GuzzleHttp\Exception\RequestException $e) {
        $values = array();
      }
      $values = is_array($values) ? $values : [$values];
      foreach($values as $value) {
        if(is_null($value)) {
          continue;
        }
        if (!empty($entity->{$field_name}['und']) && $field['cardinality'] != FIELD_CARDINALITY_UNLIMITED && count($entity->{$field_name}['und']) >= $field['cardinality']) {
          break;
        }
        $field_values = compact('value');
        switch($type) {
          case 'text':
          case 'text_long':
            $field_values['format'] = _edstep_get_field_mapping($entity_type, $key, 'format');
            break;
        }
        $entity->{$field_name}['und'][] = $field_values;
      }
    }
  }
}
function _edstep_get_field_mapping($entity_type, $field, $prop) {
  $field_mappings = variable_get('edstep_field_mappings');
  if(empty($field_mappings[$entity_type][$field][$prop])) {
    return NULL;
  }
  return $field_mappings[$entity_type][$field][$prop];
}
// TODO: add map function for each field type (text, text_long etc). Maybe filter too

// function _edstep_field_storage_is_empty_value($value) {
//   switch(gettype($value)) {
//     case 'string':
//       return empty($value);
//     case 'NULL':
//       return TRUE;
//     default:
//       return FALSE;
//   }
// }
//
// function _edstep_field_storage_is_not_empty_value($value) {
//   return !_edstep_field_storage_is_empty_value($value);
// }

/**
 * Implements hook_field_storage_write().
 */
function edstep_field_storage_write($entity_type, $entity, $op, $fields) {
  // TODO: throw error or do nothing?
}

/**
 * Implements hook_field_storage_delete().
 *
 * This function deletes data for all fields for an entity from the database.
 */
function edstep_field_storage_delete($entity_type, $entity, $fields) {
  // Do nothing
}

/**
 * Implements hook_field_storage_purge().
 *
 * This function deletes data from the database for a single field on
 * an entity.
 */
function edstep_field_storage_purge($entity_type, $entity, $field, $instance) {
  // Do nothing
}

/**
 * Implements hook_field_storage_query().
 */
function edstep_field_storage_query(EntityFieldQuery $query) {
  // TODO: throw error or do nothing?
}

/**
 * Implements hook_field_storage_delete_revision().
 *
 * This function actually deletes the data from the database.
 */
function edstep_field_storage_delete_revision($entity_type, $entity, $fields) {
  // Do nothing
}

/**
 * Implements hook_field_storage_delete_instance().
 *
 * This function simply marks for deletion all data associated with the field.
 */
function edstep_field_storage_delete_instance($instance) {
  // Do nothing
}

/**
 * Implements hook_field_attach_rename_bundle().
 */
function edstep_field_attach_rename_bundle($entity_type, $bundle_old, $bundle_new) {
  // Do nothing
}

/**
 * Implements hook_field_storage_purge_field().
 *
 * All field data items and instances have already been purged, so all
 * that is left is to delete the table.
 */
function edstep_field_storage_purge_field($field) {
  // Do nothing
}

/**
 * Implements hook_field_storage_details().
 */
function edstep_field_storage_details($field) {
  // Do nothing
}
