<?php

/**
 * @file
 * Default theme implementation to display a edstep_course.
 *
 * Available variables:
 * - $title: the (sanitized) title of the edstep_course.
 * - $content: An array of edstep_course items. Use render($content) to print them all,
 *   or print a subset such as render($content['field_example']). Use
 *   hide($content['field_example']) to temporarily suppress the printing of a
 *   given element.
 * - $date: Formatted creation date. Preprocess functions can reformat it by
 *   calling format_date() with the desired parameters on the $created variable.
 * - $name: Themed username of edstep_course author output from theme_username().
 * - $url: Direct URL of the current edstep_course.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the
 *   following:
 *   - edstep_course: The current template type; for example, "theming hook".
 *   - edstep_course-teaser: Nodes in teaser form.
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 *
 * Other variables:
 * - $edstep_course: Full edstep_course object. Contains data that may not be safe.
 * - $uid: User ID of the edstep_course author.
 * - $created: Time the edstep_course was published formatted in Unix timestamp.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *   teaser listings.
 * - $id: Position of the edstep_course. Increments each time it's output.
 *
 * Node status variables:
 * - $view_mode: View mode; for example, "full", "teaser".
 * - $teaser: Flag for the teaser state (shortcut for $view_mode == 'teaser').
 * - $page: Flag for the full page state.
 * - $readmore: Flags true if the teaser content of the edstep_course cannot hold the
 *   main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * Field variables: for each field instance attached to the edstep_course a corresponding
 * variable is defined; for example, $edstep_course->body becomes $body. When needing to
 * access a field's raw values, developers/themers are strongly encouraged to
 * use these variables. Otherwise they will have to explicitly specify the
 * desired field language; for example, $edstep_course->body['en'], thus overriding any
 * language negotiation rule that was previously applied.
 *
 * @see template_preprocess()
 * @see template_preprocess_edstep_course()
 * @see template_process()
 *
 * @ingroup themeable
 */
?>
<div id="edstep-course-<?php print $edstep_course->course_id; ?>" class="<?php print $classes; ?> clearfix"<?php print $attributes; ?>>

  <?php print render($title_prefix); ?>
  <?php if (!$page): ?>
    <h2<?php print $title_attributes; ?>><a href="<?php print $url; ?>"><?php print $title; ?></a></h2>
  <?php endif; ?>
  <?php print render($title_suffix); ?>

  <?php if($view_mode !== 'manage'): ?>
    <div class="meta submitted">
      <span property="dc:date dc:created" content="<?php print format_date($edstep_course->remote->created, 'custom', 'Y-m-d\TH:i:sP'); ?>" datatype="xsd:dateTime" rel="sioc:has_creator">
        <?php print t('Submitted by !username on !datetime', array('!username' => $name, '!datetime' => format_date($edstep_course->created))); ?>
      </span>
    </div>
  <?php endif; ?>

  <div class="content"<?php print $content_attributes; ?>>
    <?php if($edstep_course->remote->banner_image !== '') print "<img src='" . variable_get('edstep_host') . '/img/fitlarge/' . $edstep_course->remote->banner_image . "'>" ?>
    <?php
      // We hide the links now so that we can render them later.
      hide($content['links']);
      print render($content);
    ?>
  </div>

  <?php print render($content['links']); ?>

</div>
